package com.gangstar;

import com.google.android.maps.GeoPoint;

public class Area {
	
	private GeoPoint point;
	private Gangster owner;
	private String areaName;
	private int areaWealth;
	private int numberGoons;
	
	public Area(double latitude, double longitude, 
    		Gangster owner, String areaName,
    		int areaWealth, int numberGoons) {
		
        this.point = new GeoPoint(
        		(int) (latitude * 1e6),
        		(int) (longitude * 1e6));
        
        this.owner = owner;
        this.areaName = areaName;
        this.areaWealth = areaWealth;
        this.numberGoons = numberGoons;
        owner.addArea(this);
		
	}
	/**
	 * Get the GeoPoint of the area in question
	 * @author Japskua
	 * @return the point as an GeoPoint
	 */
	public GeoPoint getPoint() {
		return point;
	}
	
	public String getTopic() {
		return areaName + " - " + owner.getName();
	}
	
	public String getContent() {
		return areaWealth + "$/day\n" + numberGoons + " goons";
	}
	
	/**
	 * This function is used to change the owner of the area.
	 * This function calls the owner gangster to remove the area
	 * from it's list of owned territories and then adds itself
	 * to the list of the new owner
	 * @param newOwner the new owner as a Gangster class
	 */
	public void changeOwner(Gangster newOwner) {
		owner.removearea(this);
		owner = newOwner;
		owner.addArea(this);
	}
	
	/**
	 * Gets the owner of the Area in question
	 * @return the owner as a Gangster class
	 */
	public Gangster getOwner() {
		return owner;
	}
	
	/**
	 * Kiils the amount of troops specified from the current area
	 * The amount of goons cannot go below zero.
	 * @param amount the amount of troops to be removed
	 */
	public void killTroops(int amount) {
		numberGoons = numberGoons - amount;
		if (numberGoons < 0) {
			numberGoons = 0;
		}
	}
	
	/**
	 * 
	 * @return the number of troops on the area
	 */
	public int getTroops() {
		return numberGoons;
	}
	
	/**
	 * Adds the specified number of troops to the area
	 * in question
	 * @param amount the amount of troops to be added
	 * @return Returns true if moving troops from own henchmen
	 * to area worked. If there are not enough troops to move from
	 * own henchmen, returns false
	 */
	public boolean addTroops(int amount) {
		if (owner.getGoons() >= amount) {
			numberGoons = numberGoons + amount;
			owner.removeGoons(amount);
		}
		else {
			// Not able to move so many troops
			return false;
		}
		// Moving troops worked
		return true;
	}

}
