package com.gangstar;

import java.util.ArrayList;
import java.util.Random;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.PendingIntent;
import android.app.Instrumentation.ActivityMonitor;
import android.content.ComponentName;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.ServiceConnection;
import android.graphics.drawable.Drawable;
import android.os.IBinder;
import android.widget.EditText;
import android.widget.Toast;

import com.google.android.maps.GeoPoint;
import com.google.android.maps.ItemizedOverlay;
//import com.google.android.maps.OverlayItem;
import com.gangstar.GangstarOverlayItem;

public class GangstarItemizedOverlay extends ItemizedOverlay {
	
	private static final DistanceCalculator distanceCalculator = new DistanceCalculator(6371000);
	PlayerSingleton myPlayer = PlayerSingleton.getInstance();
	private boolean running;
	private ArrayList<GangstarOverlayItem> mOverlays = new ArrayList<GangstarOverlayItem>();
	Context mContext;
	private Area area;
	private Intent battleIntent;
	
	public GangstarItemizedOverlay(Drawable defaultMarker, Context context) {
		super(boundCenterBottom(defaultMarker));
		mContext = context;
	}

	public void addOverlay(GangstarOverlayItem overlay) {
	    mOverlays.add(overlay);
	    populate();
	}	
	
	@Override
	protected GangstarOverlayItem createItem(int i) {
		return mOverlays.get(i);
	}

	@Override
	public int size() {
		return mOverlays.size();
	}
	
	/**
	 * addTroopsListener is used to add new troops to the area in question
	 * The troops are then removed from the Players henchmen to be area defenders
	 * @author Japskua
	 */
	DialogInterface.OnClickListener addTroppsListener =
		new DialogInterface.OnClickListener() {
			
			@Override
			public void onClick(DialogInterface dialog, int which) {
				
				if (area.addTroops(5) == true) {
					Toast.makeText(mContext,
							"Ordered 5 Goons to defence",
							Toast.LENGTH_SHORT).show();	
				}
				else {
					Toast.makeText(mContext,
							"Not enough Goons left...",
							Toast.LENGTH_SHORT).show();
				}
			}
		};
	
	
	DialogInterface.OnClickListener resultListener =
			new DialogInterface.OnClickListener() {

				@Override
				public void onClick(DialogInterface dialog, int which) {
					boolean attackerWon = PlayerSingleton.getInstance().getAttackerWon(); 
					if (attackerWon == true) {
						 
						 Toast.makeText(mContext,
								 "Fight Won!!!!",
								 Toast.LENGTH_SHORT).show();
						 area.changeOwner(myPlayer.getPlayer());
						 area.killTroops(area.getTroops());
						 
					 }
					 else {
						 
						 Toast.makeText(mContext,
								 "Fight Lost!!!",
								 Toast.LENGTH_SHORT).show();
						 
						 area.killTroops((area.getTroops() - myPlayer.getTroopsLeft()));
						 myPlayer.getPlayer().removeGoons(myPlayer.getPlayer().getGoons());
					 }					
				}
			};

	/**
	 * fightListener listens if the Fight button on a certain 
	 * area is clicked. If it is, show something
	 * @author Japskua
	 * 
	 */
	DialogInterface.OnClickListener fightListner =
		new DialogInterface.OnClickListener() {
					
			@Override
			public void onClick(DialogInterface dialog, int which) {
				
				if (myPlayer.getPlayer().getGoons() == 0) 
				{
					Toast.makeText(mContext,
							"No more troops left to fight...", 
							Toast.LENGTH_SHORT).show();
				}
				else {

				 battleIntent = new Intent(mContext, GangStarBattleManager.class);
				 /**
				  * Here to add troops to battle
				  * red - attacker
				  * blue - defender
				  */
				 
				 battleIntent.putExtra("reds", myPlayer.getPlayer().getGoons());
				 battleIntent.putExtra("blues", area.getTroops());
				 
				 AlertDialog.Builder dialog2 = new AlertDialog.Builder(mContext);
					dialog2.setTitle("The has ended");
					dialog2.setMessage("The result of battle");
					dialog2.setPositiveButton("Results", resultListener);
					dialog2.show();
				 
				 mContext.startActivity(battleIntent);
				}
			}
		};
		
	/**
	 * onTap is used when the user clicks/taps the current object
	 * @author Japskua	
	 */
	@Override
	protected boolean onTap(int index) {
		GangstarOverlayItem item = mOverlays.get(index);
		AlertDialog.Builder dialog = new AlertDialog.Builder(mContext);
		
		// Create a dummy test location
        String coordinates[] = {"61.065734", "28.093766"};
        double lat = Double.parseDouble(coordinates[0]);
        double lng = Double.parseDouble(coordinates[1]);
 
        // Create the GeoPoint p and get the location the user
        GeoPoint p = myPlayer.getMyLocation();
        // Calculate the distance to the point which user tapped
		double distance = distanceCalculator.CalculationByDistance(item.getPoint(), p);

		// Create a dialog here
		// 
		this.area = item.getArea();
		dialog.setTitle(area.getTopic());
		// If the user is close enough display more information about
		// the area in question and also give
		if (distance<=250) 
		{

			dialog.setMessage(area.getContent());
		
			// If the player controls the area, give him options to give orders
			if (area.getOwner().equals(myPlayer.getPlayer())) {

				dialog.setPositiveButton("Add Goons", addTroppsListener);
				dialog.setNegativeButton("Close", null);
			}
			// If the area is controlled by someone else, give possibility
			// to contest for the ownership
			else {
			dialog.setPositiveButton("Fight", fightListner);
			dialog.setNegativeButton("Run!", null);
			}
		}
		// If the user is too far from the area, just show information
		// of the area in question
		else 
		{
			dialog.setMessage("You need to get " + (int)(distance-250) + " meters closer to get more information.");
			dialog.setNegativeButton("Back", null);
		}

		// Show the dialog
		dialog.show();
		return true;
	}
	
	
}
